@@ -1,7 +1,6 @@
 /*--------------------------------------------------------------------
- *	$Id: rotconverter.c 17560 2017-02-17 22:05:42Z pwessel $
  *
- *   Copyright (c) 1999-2017 by P. Wessel
+ *   Copyright (c) 1999-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as published by
@@ -12,7 +11,7 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU Lesser General Public License for more details.
  *
- *   Contact info: www.soest.hawaii.edu/pwessel
+ *   Contact info: www.generic-mapping-tools.org
  *--------------------------------------------------------------------*/
 /*
  * Program for converting between total reconstruction and stage poles or to add rotations.
@@ -62,71 +61,73 @@
  * 265.37800	 55.69932	150.0000	 82.9957
  */
 
-#define THIS_MODULE_NAME	"rotconverter"
+#include "gmt_dev.h"
+#include "spotter.h"
+
+#define THIS_MODULE_CLASSIC_NAME	"rotconverter"
+#define THIS_MODULE_MODERN_NAME	"rotconverter"
 #define THIS_MODULE_LIB		"spotter"
 #define THIS_MODULE_PURPOSE	"Manipulate total reconstruction and stage rotations"
 #define THIS_MODULE_KEYS	">D}"
-
-#include "spotter.h"
-
-#define GMT_PROG_OPTIONS "-:>Vh"
+#define THIS_MODULE_NEEDS	""
+#define THIS_MODULE_OPTIONS "-:>Vh"
 
 struct ROTCONVERTER_CTRL {	/* All control options for this program (except common args) */
 	/* active is true if the option has been activated */
-	struct A {	/* -A */
+	struct ROTCONVERTER_A {	/* -A */
 		bool active;
 	} A;
-	struct D {	/* -D */
+	struct ROTCONVERTER_D {	/* -D */
 		bool active;
 	} D;
-	struct E {	/* -E[<value>] */
-		bool active;
-		double value;
-	} E;
-	struct F {	/* -F */
+	struct ROTCONVERTER_F {	/* -F */
 		bool active;
 		bool mode;	/* out mode (true if total reconstruction rotations) */
 	} F;
-	struct G {	/* -G */
+	struct ROTCONVERTER_G {	/* -G */
 		bool active;
 	} G;
-	struct N {	/* -N */
+	struct ROTCONVERTER_M {	/* -M[<value>] */
+		bool active;
+		double value;
+	} M;
+	struct ROTCONVERTER_N {	/* -N */
 		bool active;
 	} N;
-	struct S {	/* -S */
+	struct ROTCONVERTER_S {	/* -S */
 		bool active;
 	} S;
-	struct T {	/* -T */
+	struct ROTCONVERTER_T {	/* -T */
 		bool active;
 	} T;
-	struct W {	/* -W */
+	struct ROTCONVERTER_W {	/* -W */
 		bool active;
 	} W;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct ROTCONVERTER_CTRL *C;
-	
+
 	C = gmt_M_memory (GMT, NULL, 1, struct ROTCONVERTER_CTRL);
-	
+
 	/* Initialize values whose defaults are not 0/false/NULL */
-	
-	C->E.value = 0.5;	/* To get half-angles */
+
+	C->M.value = 0.5;	/* To get half-angles */
 	C->F.mode = true;	/* Default format is total reconstruction rotation poles for both input and output */
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	gmt_M_free (GMT, C);	
+	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
-	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+static int usage (struct GMTAPI_CTRL *API, int level) {
+	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
-	GMT_Message (API, GMT_TIME_NONE, "usage: rotconverter [+][-] <rotA> [[+][-] <rotB>] [[+][-] <rotC>] ... [-A] [-D] [-E[<factor>]]\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t[-F<out>] [-G] [-N] [-S] [-T] [%s] [-W]\n\t[%s] > outfile\n\n", GMT_V_OPT, GMT_h_OPT);
-	
+	GMT_Message (API, GMT_TIME_NONE, "usage: %s [+][-] <rotA> [[+][-] <rotB>] [[+][-] <rotC>] ... [-A] [-D]\n", name);
+	GMT_Message (API, GMT_TIME_NONE, "\t[-F<out>] [-G] [-M[<factor>]] [-N] [-S] [-T] [%s] [-W]\n\t[%s] [%s]\n\n", GMT_V_OPT, GMT_h_OPT, GMT_PAR_OPT);
+
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t<rotA>, <rotB>, etc. are total reconstruction or stage rotation pole files.\n");
@@ -138,10 +139,10 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-A Report angles as time [Default uses time].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-D Report all longitudes in -180/+180 range [Default is 0-360].\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t-E Reduce opening angles for stage rotations by <factor> [0.5].\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t   Typically used to get half-rates needed for flowlines.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-F Set output file type: t for total reconstruction and s for stage rotations [Default is -Ft].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-G Write rotations using GPlates format [Default is spotter format].\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-M Reduce opening angles for stage rotations by <factor> [0.5].\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   Typically used to get half-rates needed for flowlines.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-N Ensure all poles are in northern hemisphere [Default ensures positive opening angles/rates].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-S Ensure all poles are in southern hemisphere [Default ensures positive opening angles/rates].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-T Transpose the result (i.e., change sign of final rotation angle).\n");
@@ -149,11 +150,11 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t-W Ensure all rotations have negative opening angles/rates [Default ensures positive opening angles/rates].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Only one of -N, -S, -W may be used at the same time.\n");
 	GMT_Option (API, "h,.");
-	
+
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to rotconverter and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -171,7 +172,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struc
 				break;
 
 			/* Supplemental parameters */
-			
+
 			case 'A':	/* Angle, not time */
 				Ctrl->A.active = true;
 				break;
@@ -179,27 +180,36 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struc
 				Ctrl->D.active = true;
 				break;
 
-			case 'E':	/* Convert to total reconstruction rotation poles instead */
-				Ctrl->E.active = true;
-				if (opt->arg[0]) Ctrl->E.value = atof (opt->arg);
+			case 'E':	/* Convert to half-spreading stage rotations [NOW -M] */
+				if (gmt_M_compat_check (GMT, 5)) { /* Warn and fall through */
+					GMT_Report (API, GMT_MSG_COMPAT, "-E is deprecated; use -M instead.\n");
+					Ctrl->M.active = true;
+					if (opt->arg[0]) Ctrl->M.value = atof (opt->arg);
+				}
+				else {
+					GMT_Report (API, GMT_MSG_ERROR, "No such option -E\n");
+					n_errors++;
+				}
 				break;
 
 			case 'F':
 				Ctrl->F.active = true;
 				if (strlen (opt->arg) != 1) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Error: Must specify -F<out>\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Must specify -F<out>\n");
 					n_errors++;
 					continue;
 				}
 				switch (opt->arg[0]) {	/* Output format */
 					case 'f':
 						if (gmt_M_compat_check (GMT, 4)) /* Warn and fall through */
-							GMT_Report (API, GMT_MSG_COMPAT, "Warning: -Ff is deprecated; use -Ft instead.\n");
+							GMT_Report (API, GMT_MSG_COMPAT, "-Ff is deprecated; use -Ft instead.\n");
+							/* Intentionally fall through - to 't' */
 						else {
-							GMT_Report (API, GMT_MSG_NORMAL, "Error: Must specify t|s\n");
+							GMT_Report (API, GMT_MSG_ERROR, "Must specify t|s\n");
 							n_errors++;
 							break;
 						}
+						/* Intentionally fall through */
 					case 't':
 						Ctrl->F.mode = true;
 						break;
@@ -207,7 +217,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struc
 						Ctrl->F.mode = false;
 						break;
 					default:
-						GMT_Report (API, GMT_MSG_NORMAL, "Error: Must specify t|s\n");
+						GMT_Report (API, GMT_MSG_ERROR, "Must specify t|s\n");
 						n_errors++;
 						break;
 				}
@@ -217,6 +227,11 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struc
 				Ctrl->G.active = true;
 				break;
 
+			case 'M':	/* Convert to total reconstruction rotation poles instead */
+				Ctrl->M.active = true;
+				if (opt->arg[0]) Ctrl->M.value = atof (opt->arg);
+				break;
+
 			case 'N':	/* Ensure all poles reported are in northern hemisphere */
 				Ctrl->N.active = true;
 				break;
@@ -236,16 +251,16 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struc
 			case '0': case '1': case '2': case '3': case '4': case '5': case '6':
 				case '7': case '8': case '9': case '.':
 				break;	/* Probably a rotation lon/lat/angle with negative longitude */
-				
+
 			default:	/* Report bad options */
 				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	n_errors += gmt_M_check_condition (GMT, (Ctrl->S.active + Ctrl->N.active + Ctrl->W.active) > 1, "Syntax error: Specify only one of -N, -S, and -W!\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->E.active && Ctrl->F.mode, "Syntax error: -E requires stage rotations on output\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->G.active && !Ctrl->F.mode, "Syntax error: -G requires total reconstruction rotations on output\n");
+	n_errors += gmt_M_check_condition (GMT, (Ctrl->S.active + Ctrl->N.active + Ctrl->W.active) > 1, "Specify only one of -N, -S, and -W!\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->M.active && Ctrl->F.mode, "Option -M requires stage rotations on output.  Please add -Fs\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->G.active && !Ctrl->F.mode, "Option -G requires total reconstruction rotations on output\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
@@ -253,7 +268,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTCONVERTER_CTRL *Ctrl, struc
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_rotconverter (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_rotconverter (void *V_API, int mode, void *args) {
 	struct EULER *p = NULL;			/* Pointer to array of stage poles */
 	struct EULER *a = NULL, *b = NULL;	/* Pointer to arrays of stage poles */
 
@@ -276,8 +291,8 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 	char *end_text[2] = {"tend(My)", "aend(deg)"};
 	char *time_text[2] = {"ttime(My)", "tangle(deg)"};
 	char record[GMT_BUFSIZ] = {""};
-	
 
+	struct GMT_RECORD *Out = NULL;
 	struct GMT_OPTION *ptr = NULL, *opt = NULL;
 	struct ROTCONVERTER_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
@@ -295,10 +310,10 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 	 * have been decoded as options -4 and option -., respectively.  Here we simply
 	 * undo these and make them all "file" options -<.
 	 * Also, a single - sign would have been decoded as the synopsis option.  */
-	
+
 	for (opt = options; opt; opt = opt->next, n_opt++) {
 		switch (opt->option) {
-			case '0': case '1': case '2': case '3': case '4': case '5': 
+			case '0': case '1': case '2': case '3': case '4': case '5':
 			case '6': case '7': case '8': case '9': case '.':
 				sprintf (record, "-%c%s", opt->option, opt->arg);
 				gmt_M_str_free (opt->arg);
@@ -320,8 +335,8 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
-	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	if ((ptr = GMT_Find_Option (API, 'f', options)) == NULL) gmt_parse_common_options (GMT, "f", 'f', "g"); /* Did not set -f, implicitly set -fg */
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
@@ -330,12 +345,13 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 
 	gmt_M_memset (out, 20, double);
 	if (Ctrl->G.active) {
-		GMT->current.io.col_type[GMT_OUT][0] = GMT->current.io.col_type[GMT_OUT][1] = GMT_IS_FLOAT;
-		GMT->current.io.col_type[GMT_OUT][2] = GMT_IS_LAT;
-		GMT->current.io.col_type[GMT_OUT][3] = GMT_IS_LON;
+		gmt_set_column (GMT, GMT_OUT, 0, GMT_IS_FLOAT);
+		gmt_set_column (GMT, GMT_OUT, 1, GMT_IS_FLOAT);
+		gmt_set_column (GMT, GMT_OUT, 2, GMT_IS_LAT);
+		gmt_set_column (GMT, GMT_OUT, 3, GMT_IS_LON);
 		strcpy (GMT->current.setting.format_float_out, "%g");
 	}
-	
+
 	last_sign = +1;
 	for (opt = options; opt; opt = opt->next) {
 		if (opt->option != GMT_OPT_INFILE) continue;	/* Only consider files (or rotations) from here on */
@@ -357,7 +373,7 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 		else if (gmt_access (GMT, opt->arg, R_OK)) {	/* Not a readable file, is it a lon/lat/t0[/t1]/omega specification? */
 			for (k = n_slash = 0; opt->arg[k]; k++) if (opt->arg[k] == '/') n_slash++;
 			if (n_slash < 2 || n_slash > 4) {	/* No way it can be a online rotation, cry foul */
-				GMT_Report (API, GMT_MSG_NORMAL, "Error: Cannot read file %s\n", opt->arg);
+				GMT_Report (API, GMT_MSG_ERROR, "Cannot read file %s\n", opt->arg);
 				gmt_M_free (GMT, a);
 				Return (GMT_RUNTIME_ERROR);
 			}
@@ -367,11 +383,11 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 				if (k == 4) angle = t1, t1 = 0.0;			/* Only 4 input values */
 				if (n_slash == 2) angle = t0, t0 = 1.0, t1 = 0.0, no_time = true;	/* Quick lon/lat/angle total reconstruction rotation, no time */
 				if (t0 < t1) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Error: Online rotation has t_start (%g) younger than t_stop (%g)\n", t0, t1);
+					GMT_Report (API, GMT_MSG_ERROR, "Online rotation has t_start (%g) younger than t_stop (%g)\n", t0, t1);
 					Return (GMT_RUNTIME_ERROR);
 				}
 				if (angle == 0.0) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Error: Online rotation has zero opening angle\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Online rotation has zero opening angle\n");
 					Return (GMT_RUNTIME_ERROR);
 				}
 				online_rot = true;
@@ -392,7 +408,7 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 				if (online_stage) spotter_stages_to_total (GMT, a, n_a, true, true);
 			}
 			else
-				n_a = spotter_init (GMT, opt->arg, &a, false, true, false, &zero);	/* Return total reconstruction rotations */
+				n_a = spotter_init (GMT, opt->arg, &a, 0, true, false, &zero);	/* Return total reconstruction rotations */
 			zero = 0.0;
 			if (last_sign == -1) {	/* Leading - sign, simply reverse the rotation angles */
 				for (stage = 0; stage < n_a; stage++) {
@@ -414,7 +430,7 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 				if (online_stage) spotter_stages_to_total (GMT, b, n_b, true, true);
 			}
 			else
-				n_b = spotter_init (GMT, opt->arg, &b, false, true, false, &zero);	/* Return total reconstruction rotations */
+				n_b = spotter_init (GMT, opt->arg, &b, 0, true, false, &zero);	/* Return total reconstruction rotations */
 			zero = 0.0;
 			spotter_add_rotations (GMT, a, n_a, b, last_sign * n_b, &p, &n_p);		/* Add the two total reconstruction rotations sets, returns total reconstruction rotations in p */
 			gmt_M_free (GMT, a);
@@ -424,12 +440,16 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 		}
 	}
 
+	if (a == NULL) {
+		GMT_Report (API, GMT_MSG_ERROR, "No rotation resulting from operation\n");
+		Return (GMT_RUNTIME_ERROR);
+	}
 	n_out = 3 + ((Ctrl->F.mode) ? 1 - no_time : 2);
 	if (online_rot && n_out > 3) n_out--;
 	if (a[0].has_cov) n_out += 9;
 	if (Ctrl->G.active) n_out = 6;
-	
-	if ((error = gmt_set_cols (GMT, GMT_OUT, n_out)) != GMT_NOERROR) {
+
+	if ((error = GMT_Set_Columns (API, GMT_OUT, n_out, GMT_COL_FIX_NO_TEXT)) != GMT_NOERROR) {
 		gmt_M_free (GMT, a);
 		Return (error);
 	}
@@ -446,19 +466,20 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 		Return (API->error);
 	}
 
+	Out = gmt_new_record (GMT, out, NULL);	/* Since we only need to worry about numerics in this module */
 	if (Ctrl->G.active)		/* GPlates header */
-		sprintf (record, "#plateid%stime%slatitude%slongitude%sangle%sfixedplateid\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, \
+		sprintf (record, "plateid%stime%slatitude%slongitude%sangle%sfixedplateid\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, \
 			GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator);
 	else if (Ctrl->F.mode && no_time)
-		sprintf (record, "#longitude%slatitude%sangle(deg)\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator);
+		sprintf (record, "longitude%slatitude%sangle(deg)\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator);
 	else if (Ctrl->F.mode)	/* Easy, simply output what we've got following a header*/
-		sprintf (record, "#longitude%slatitude%s%s%sangle(deg)\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, time_text[Ctrl->A.active], GMT->current.setting.io_col_separator);
+		sprintf (record, "longitude%slatitude%s%s%sangle(deg)\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, time_text[Ctrl->A.active], GMT->current.setting.io_col_separator);
 	else {	/* Convert total reconstruction to stages before output */
 		spotter_total_to_stages (GMT, a, n_a, true, true);				/* To ensure we have the right kind of poles for output */
-		printf (record, "#longitude%slatitude%s%s%s%s%sangle(deg)\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, start_text[Ctrl->A.active], GMT->current.setting.io_col_separator, end_text[Ctrl->A.active], GMT->current.setting.io_col_separator);
+		printf (record, "longitude%slatitude%s%s%s%s%sangle(deg)\n", GMT->current.setting.io_col_separator, GMT->current.setting.io_col_separator, start_text[Ctrl->A.active], GMT->current.setting.io_col_separator, end_text[Ctrl->A.active], GMT->current.setting.io_col_separator);
 	}
 	if (GMT->current.setting.io_header[GMT_OUT]) GMT_Put_Record (API, GMT_WRITE_TABLE_HEADER, record);
-	
+
 	for (stage = 0; stage < n_a; stage++) {
 		if (Ctrl->T.active) a[stage].omega = -a[stage].omega;
 		if ((Ctrl->W.active && a[stage].omega > 0.0) || (Ctrl->S.active && a[stage].lat > 0.0) || (Ctrl->N.active && a[stage].lat < 0.0) || (!(Ctrl->S.active || Ctrl->N.active || Ctrl->W.active) && a[stage].omega < 0.0))	/* flip to antipole */
@@ -467,7 +488,7 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 		while (a[stage].lon <= -180.0) a[stage].lon += 360.0;				/* Force geodetic longitude range */
 		while (!Ctrl->D.active && a[stage].lon < 0.0) a[stage].lon += 360.0;		/* Force geodetic longitude range */
 		while (Ctrl->D.active && a[stage].lon > 180.0) a[stage].lon -= 360.0;		/* Force a geographic longitude range */
-		if (Ctrl->E.active) a[stage].omega *= Ctrl->E.value;
+		if (Ctrl->M.active) a[stage].omega *= Ctrl->M.value;
 		out[GMT_X] = a[stage].lon;	out[GMT_Y] = a[stage].lat;
 		col = 2;
 		if (Ctrl->G.active) {
@@ -494,14 +515,15 @@ int GMT_rotconverter (void *V_API, int mode, void *args) {
 			spotter_covar_to_record (GMT, &a[stage], K);
 			for (k = 0; k < 9; k++) out[col++] = K[k];
 		}
-		GMT_Put_Record (API, GMT_WRITE_DATA, out);
+		GMT_Put_Record (API, GMT_WRITE_DATA, Out);
 	}
-	
+
 	gmt_M_free (GMT, a);
+	gmt_M_free (GMT, Out);
 
 	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) {		/* Disables further data output */
 		Return (API->error);
 	}
-	
+
 	Return (GMT_NOERROR);
 }
